#!/bin/bash

#### This script is part of "RNA-seq data analysis: from raw reads to differential expression" tutorial of keepsciencegoing.org initiative. 
#### You can find explanations and references in the related videos under keepsciencegoing.org
#### The script is provided "as is" for educational purposes. 
#### Author: Daniele Tavernari ( daniele.tavernari@unil.ch ), Date: 12th April 2020

# Define your base directory
basedir="/path_to_your_base_directory/"

# Define your Tools directory and your Data directory (where you have your fastq files)
ToolsDir=${basedir}"Tools/"

# Create a folder for your reference, download and decompress genome and GTF files in it
mkdir -p ${ToolsDir}"/ref_ucsc_hg38"
cd ${ToolsDir}"/ref_ucsc_hg38/"
curl -LOJ "https://hgdownload.soe.ucsc.edu/goldenPath/hg38/bigZips/hg38.fa.gz" # hg38 fasta file with reference genome
gzip -d "hg38.fa.gz"
curl -LOJ "https://hgdownload.soe.ucsc.edu/goldenPath/hg38/bigZips/genes/hg38.refGene.gtf.gz" # 'hg38.ensGene.gtf.gz' with Ensembl IDs is probably more complete, but 'refGene' contains directly gene names we are familiar with.
gzip -d "hg38.refGene.gtf.gz"

# Indexing with STAR. It will take quite some time (~hours)... but you will do it only once. You can also set to use multiple threads with the option '--runThreadN'.
${ToolsDir}STAR-2.7.3a/bin/Linux_x86_64/STAR --runMode genomeGenerate --genomeDir ${ToolsDir}"/ref_ucsc_hg38/" --genomeFastaFiles ${ToolsDir}"/ref_ucsc_hg38/hg38.fa" --sjdbGTFfile ${ToolsDir}"/ref_ucsc_hg38/hg38.refGene.gtf"
